@@ -300,10 +300,12 @@ func CheckPkgVersionIsNotQuoted(apkbuild *Apkbuild, getenv func(string) string)
 }
 
 func CheckGlobalVariableIsNotEmpty(apkbuild *Apkbuild, getenv func(string) string) (violations []LintingViolation) {
+	allowedEmptyVariables := map[string]struct{}{
+		"arch":       {}, // has a default value, so setting it empty has an effect
+		"maintainer": {}, // unmaintained packages have an empty maintainer
+	}
 	apkbuild.GlobalVariables.Iter(func(v Variable) {
-		if v.Name == "arch" {
-			// 'arch' has a default value set, so setting it to empty has an effect. It's
-			// done to temporarily disable a package.
+		if _, allowedEmpty := allowedEmptyVariables[v.Name]; allowedEmpty {
 			return
 		}
 		if !strings.HasPrefix(v.Name, "_") && v.Value == "" {
